@@ -69,10 +69,6 @@ class Angle(u.SpecificTypeQuantity):
       <Angle 1.04166667 hourangle>
       >>> Angle('-1:2.5', unit=u.deg)
       <Angle -1.04166667 deg>
-      >>> Angle((10, 11, 12), unit='hourangle')  # (h, m, s)
-      <Angle 10.18666667 hourangle>
-      >>> Angle((-1, 2, 3), unit=u.deg)  # (d, m, s)
-      <Angle -1.03416667 deg>
       >>> Angle(10.2345 * u.deg)
       <Angle 10.2345 deg>
       >>> Angle(Angle(10.2345 * u.deg))
@@ -124,7 +120,15 @@ class Angle(u.SpecificTypeQuantity):
                     angle_unit = unit
 
                 if isinstance(angle, tuple):
-                    angle = cls._tuple_to_float(angle, angle_unit)
+                    if angle_unit == u.hourangle:
+                        form._check_hour_range(angle[0])
+                    form._check_minute_range(angle[1])
+                    a = np.abs(angle[0]) + angle[1] / 60.
+                    if len(angle) == 3:
+                        form._check_second_range(angle[2])
+                        a += angle[2] / 3600.
+
+                    angle = np.copysign(a, angle[0])
 
                 if angle_unit is not unit:
                     # Possible conversion to `unit` will be done below.
@@ -252,6 +256,9 @@ class Angle(u.SpecificTypeQuantity):
 
             - 'latex': Return a LaTeX-formatted string
 
+            - 'latex_inline': Return a LaTeX-formatted string which is the
+              same as with ``format='latex'`` for |Angle| instances
+
             - 'unicode': Return a string containing non-ASCII unicode
               characters, such as the degree symbol
 
@@ -278,6 +285,9 @@ class Angle(u.SpecificTypeQuantity):
                 u.degree: '°′″',
                 u.hourangle: 'ʰᵐˢ'}
         }
+        # 'latex_inline' provides no functionality beyond what 'latex' offers,
+        # but it should be implemented to avoid ValueErrors in user code.
+        separators['latex_inline'] = separators['latex']
 
         if sep == 'fromunit':
             if format not in separators:
@@ -328,7 +338,7 @@ class Angle(u.SpecificTypeQuantity):
             elif sep == 'fromunit':
                 values = self.to_value(unit)
                 unit_string = unit.to_string(format=format)
-                if format == 'latex':
+                if format == 'latex' or format == 'latex_inline':
                     unit_string = unit_string[1:-1]
 
                 if precision is not None:
@@ -355,7 +365,7 @@ class Angle(u.SpecificTypeQuantity):
                 s = func(float(val))
                 if alwayssign and not s.startswith('-'):
                     s = '+' + s
-                if format == 'latex':
+                if format == 'latex' or format == 'latex_inline':
                     s = f'${s}$'
                 return s
             s = f"{val}"
@@ -573,8 +583,8 @@ class Latitude(Angle):
         # objects, for speed.
         if angles is None:
             angles = self
-        lower = u.degree.to(angles.unit, -90.0)
-        upper = u.degree.to(angles.unit, 90.0)
+        upper = self.dtype.type(u.degree.to(angles.unit, 90.0))
+        lower = -upper
         # This invalid catch block can be removed when the minimum numpy
         # version is >= 1.19 (NUMPY_LT_1_19)
         with np.errstate(invalid='ignore'):
