@@ -12,7 +12,7 @@ standard, see the NASA/Science Office of Standards and Technology
 publication, NOST 100-2.0.
 """
 
-from ... import config as _config
+from astropy import config as _config
 
 # Set module-global boolean variables
 # TODO: Make it possible to set these variables via environment variables
@@ -36,8 +36,8 @@ class Conf(_config.ConfigNamespace):
         'treated as case-sensitive.')
     strip_header_whitespace = _config.ConfigItem(
         True,
-        'If True, automatically remove trailing whitespace for string values in '
-        'headers.  Otherwise the values are returned verbatim, with all '
+        'If True, automatically remove trailing whitespace for string values in'
+        ' headers. Otherwise the values are returned verbatim, with all '
         'whitespace intact.')
     use_memmap = _config.ConfigItem(
         True,
