@@ -6,7 +6,6 @@ import pytest
 asdf = pytest.importorskip('asdf')
 
 import datetime
-from collections import OrderedDict
 
 import numpy as np
 
@@ -18,7 +17,7 @@ import asdf.schema as asdf_schema
 
 
 def _flatten_combiners(schema):
-    newschema = OrderedDict()
+    newschema = dict()
 
     def add_entry(path, schema, combiner):
         # TODO: Simplify?
@@ -31,13 +30,13 @@ def _flatten_combiners(schema):
                     cursor.append({})
                 cursor = cursor[part]
             elif part == 'items':
-                cursor = cursor.setdefault('items', OrderedDict())
+                cursor = cursor.setdefault('items', dict())
             else:
-                cursor = cursor.setdefault('properties', OrderedDict())
+                cursor = cursor.setdefault('properties', dict())
                 if i < len(path) - 1 and isinstance(path[i+1], int):
                     cursor = cursor.setdefault(part, [])
                 else:
-                    cursor = cursor.setdefault(part, OrderedDict())
+                    cursor = cursor.setdefault(part, dict())
 
         cursor.update(schema)
 
@@ -82,15 +81,23 @@ def test_time_with_location_1_0_0(tmpdir):
 
 
 def test_isot(tmpdir):
+    isot = time.Time('2000-01-01T00:00:00.000')
+
     tree = {
-        'time': time.Time('2000-01-01T00:00:00.000')
+        'time': isot
     }
 
     helpers.assert_roundtrip_tree(tree, tmpdir)
 
     ff = asdf.AsdfFile(tree)
     tree = yamlutil.custom_tree_to_tagged_tree(ff.tree, ff)
-    assert isinstance(tree['time'], str)
+    if isinstance(tree['time'], str):
+        assert str(tree['time']) == isot.value
+    elif isinstance(tree['time'], dict):
+        assert str(tree['time']['value']) == isot.value
+        assert str(tree['time']['base_format']) == "isot"
+    else:
+        assert False
 
 
 def test_isot_array(tmpdir):
