@@ -15,11 +15,10 @@ import operator
 
 import numpy as np
 
-from astropy.units import Quantity
+from astropy.units import MagUnit, Quantity
 from astropy.utils import isiterable
-from .utils import array_repr_oneline
-from .utils import get_inputs_and_params
 
+from .utils import array_repr_oneline, get_inputs_and_params
 
 __all__ = ['Parameter', 'InputParameterError', 'ParameterError']
 
@@ -179,6 +178,8 @@ class Parameter:
     bounds : tuple
         specify min and max as a single tuple--bounds may not be specified
         simultaneously with min or max
+    mag : bool
+        Specify if the unit of the parameter can be a Magnitude unit or not
     """
 
     constraints = ('fixed', 'tied', 'bounds')
@@ -192,7 +193,7 @@ class Parameter:
 
     def __init__(self, name='', description='', default=None, unit=None,
                  getter=None, setter=None, fixed=False, tied=False, min=None,
-                 max=None, bounds=None, prior=None, posterior=None):
+                 max=None, bounds=None, prior=None, posterior=None, mag=False):
         super().__init__()
 
         self._model = None
@@ -206,13 +207,15 @@ class Parameter:
         if isinstance(default, Quantity):
             if unit is not None and not unit.is_equivalent(default.unit):
                 raise ParameterDefinitionError(
-                    "parameter default {0} does not have units equivalent to "
-                    "the required unit {1}".format(default, unit))
+                    f"parameter default {default} does not have units equivalent to "
+                    f"the required unit {unit}")
             unit = default.unit
             default = default.value
 
         self._default = default
-        self._unit = unit
+
+        self._mag = mag
+        self._set_unit(unit, force=True)
         # Internal units correspond to raw_units held by the model in the
         # previous implementation. The private _getter and _setter methods
         # use this to convert to and from the public unit defined for the
@@ -230,8 +233,8 @@ class Parameter:
         if bounds is not None:
             if min is not None or max is not None:
                 raise ValueError(
-                    'bounds may not be specified simultaneously with min or '
-                    'max when instantiating Parameter {}'.format(name))
+                    "bounds may not be specified simultaneously with min or "
+                    f"max when instantiating Parameter {name}")
         else:
             bounds = (min, max)
 
@@ -272,7 +275,7 @@ class Parameter:
             if len(oldvalue[key]) == 0:
                 raise InputParameterError(
                     "Slice assignment outside the parameter dimensions for "
-                    "'{}'".format(self.name))
+                    f"'{self.name}'")
             for idx, val in zip(range(*key.indices(len(self))), value):
                 self.__setitem__(idx, val)
         else:
@@ -280,8 +283,8 @@ class Parameter:
                 oldvalue[key] = value
             except IndexError:
                 raise InputParameterError(
-                    "Input dimension {} invalid for {!r} parameter with "
-                    "dimension {}".format(key, self.name, value.shape[0]))  # likely wrong
+                    f"Input dimension {key} invalid for {self.name!r} parameter with "
+                    f"dimension {value.shape[0]}")  # likely wrong
 
     def __repr__(self):
         args = f"'{self._name}'"
@@ -366,6 +369,10 @@ class Parameter:
 
     def _set_unit(self, unit, force=False):
         if force:
+            if isinstance(unit, MagUnit) and not self._mag:
+                raise ValueError(
+                    f"This parameter does not support the magnitude units such as {unit}"
+                )
             self._unit = unit
         else:
             self.unit = unit
@@ -400,7 +407,7 @@ class Parameter:
             raise TypeError("The .quantity attribute should be set "
                             "to a Quantity object")
         self.value = quantity.value
-        self._unit = quantity.unit
+        self._set_unit(quantity.unit, force=True)
 
     @property
     def shape(self):
@@ -671,7 +678,7 @@ class Parameter:
         arr = np.asarray(self.value, dtype=dtype)
 
         if self.unit is not None:
-            arr = Quantity(arr, self.unit, copy=False)
+            arr = Quantity(arr, self.unit, copy=False, subok=True)
 
         return arr
 
@@ -686,8 +693,6 @@ class Parameter:
     __rmul__ = _binary_arithmetic_operation(operator.mul, reflected=True)
     __pow__ = _binary_arithmetic_operation(operator.pow)
     __rpow__ = _binary_arithmetic_operation(operator.pow, reflected=True)
-    __div__ = _binary_arithmetic_operation(operator.truediv)
-    __rdiv__ = _binary_arithmetic_operation(operator.truediv, reflected=True)
     __truediv__ = _binary_arithmetic_operation(operator.truediv)
     __rtruediv__ = _binary_arithmetic_operation(operator.truediv,
                                                 reflected=True)
