@@ -5,13 +5,13 @@ Power law model variants
 # pylint: disable=invalid-name
 import numpy as np
 
-from astropy.units import Quantity
-from .core import Fittable1DModel
-from .parameters import Parameter, InputParameterError
+from astropy.units import Magnitude, Quantity, UnitsError, dimensionless_unscaled, mag
 
+from .core import Fittable1DModel
+from .parameters import InputParameterError, Parameter
 
 __all__ = ['PowerLaw1D', 'BrokenPowerLaw1D', 'SmoothlyBrokenPowerLaw1D',
-           'ExponentialCutoffPowerLaw1D', 'LogParabola1D']
+           'ExponentialCutoffPowerLaw1D', 'LogParabola1D', 'Schechter1D']
 
 
 class PowerLaw1D(Fittable1DModel):
@@ -238,7 +238,7 @@ class SmoothlyBrokenPowerLaw1D(Fittable1DModel):
 
     """
 
-    amplitude = Parameter(default=1, min=0, description="Peak value at break point")
+    amplitude = Parameter(default=1, min=0, description="Peak value at break point", mag=True)
     x_break = Parameter(default=1, description="Break point")
     alpha_1 = Parameter(default=-2, description="Power law index before break point")
     alpha_2 = Parameter(default=2, description="Power law index after break point")
@@ -288,15 +288,13 @@ class SmoothlyBrokenPowerLaw1D(Fittable1DModel):
         if i.max():
             # In this case the main formula reduces to a simple power
             # law with index `alpha_2`.
-            f[i] = amplitude * xx[i] ** (-alpha_2) \
-                   / (2. ** ((alpha_1 - alpha_2) * delta))
+            f[i] = amplitude * xx[i] ** (-alpha_2) / (2. ** ((alpha_1 - alpha_2) * delta))
 
         i = logt < -threshold
         if i.max():
             # In this case the main formula reduces to a simple power
             # law with index `alpha_1`.
-            f[i] = amplitude * xx[i] ** (-alpha_1) \
-                   / (2. ** ((alpha_1 - alpha_2) * delta))
+            f[i] = amplitude * xx[i] ** (-alpha_1) / (2. ** ((alpha_1 - alpha_2) * delta))
 
         i = np.abs(logt) <= threshold
         if i.max():
@@ -304,11 +302,10 @@ class SmoothlyBrokenPowerLaw1D(Fittable1DModel):
             # we will evaluate the whole formula.
             t = np.exp(logt[i])
             r = (1. + t) / 2.
-            f[i] = amplitude * xx[i] ** (-alpha_1) \
-                   * r ** ((alpha_1 - alpha_2) * delta)
+            f[i] = amplitude * xx[i] ** (-alpha_1) * r ** ((alpha_1 - alpha_2) * delta)
 
         if return_unit:
-            return Quantity(f, unit=return_unit, copy=False)
+            return Quantity(f, unit=return_unit, copy=False, subok=True)
         return f
 
     @staticmethod
@@ -357,14 +354,14 @@ class SmoothlyBrokenPowerLaw1D(Fittable1DModel):
             t = np.exp(logt[i])
             r = (1. + t) / 2.
             f[i] = amplitude * xx[i] ** (-alpha_1) \
-                   * r ** ((alpha_1 - alpha_2) * delta)
+                * r ** ((alpha_1 - alpha_2) * delta)
 
             d_amplitude[i] = f[i] / amplitude
             d_x_break[i] = f[i] * (alpha_1 - (alpha_1 - alpha_2) * t / 2. / r) / x_break
             d_alpha_1[i] = f[i] * (-np.log(xx[i]) + delta * np.log(r))
             d_alpha_2[i] = f[i] * (-delta * np.log(r))
             d_delta[i] = f[i] * (alpha_1 - alpha_2) \
-                         * (np.log(r) - t / (1. + t) / delta * np.log(xx[i]))
+                * (np.log(r) - t / (1. + t) / delta * np.log(xx[i]))
 
         return [d_amplitude, d_x_break, d_alpha_1, d_alpha_2, d_delta]
 
@@ -465,9 +462,12 @@ class LogParabola1D(Fittable1DModel):
 
     Notes
     -----
-    Model formula (with :math:`A` for ``amplitude`` and :math:`\\alpha` for ``alpha`` and :math:`\\beta` for ``beta``):
+    Model formula (with :math:`A` for ``amplitude`` and
+    :math:`\\alpha` for ``alpha`` and :math:`\\beta` for ``beta``):
 
-        .. math:: f(x) = A \\left(\\frac{x}{x_{0}}\\right)^{- \\alpha - \\beta \\log{\\left (\\frac{x}{x_{0}} \\right )}}
+        .. math:: f(x) = A \\left(
+                \\frac{x}{x_{0}}\\right)^{- \\alpha - \\beta \\log{\\left (\\frac{x}{x_{0}}
+            \\right )}}
 
     """
 
@@ -507,3 +507,127 @@ class LogParabola1D(Fittable1DModel):
     def _parameter_units_for_data_units(self, inputs_unit, outputs_unit):
         return {'x_0': inputs_unit[self.inputs[0]],
                 'amplitude': outputs_unit[self.outputs[0]]}
+
+
+class Schechter1D(Fittable1DModel):
+    r"""
+    Schechter luminosity function (`Schechter 1976
+    <https://ui.adsabs.harvard.edu/abs/1976ApJ...203..297S/abstract>`_),
+    parameterized in terms of magnitudes.
+
+    Parameters
+    ----------
+    phi_star : float
+        The normalization factor in units of number density.
+
+    m_star : float
+        The characteristic magnitude where the power-law form of the
+        function cuts off. Must not have units.
+
+    alpha : float
+        The power law index, also known as the faint-end slope. Must not
+        have units.
+
+    See Also
+    --------
+    PowerLaw1D, ExponentialCutoffPowerLaw1D, BrokenPowerLaw1D
+
+    Notes
+    -----
+    Model formula (with :math:`\phi^{*}` for ``phi_star``, :math:`M^{*}`
+    for ``m_star``, and :math:`\alpha` for ``alpha``):
+
+    .. math::
+
+        n(M) \ dM = (0.4 \ln 10) \ \phi^{*} \
+            [{10^{0.4 (M^{*} - M)}}]^{\alpha + 1} \
+            \exp{[-10^{0.4 (M^{*} - M)}]} \ dM
+
+    ``phi_star`` is the normalization factor in units of number density.
+    ``m_star`` is the characteristic magnitude where the power-law form
+    of the function cuts off into the exponential form. ``alpha`` is
+    the power-law index, defining the faint-end slope of the luminosity
+    function.
+
+    Examples
+    --------
+    .. plot::
+        :include-source:
+
+        from astropy.modeling.models import Schechter1D
+        import astropy.units as u
+        import matplotlib.pyplot as plt
+        import numpy as np
+
+        phi_star = 4.3e-4 * (u.Mpc ** -3)
+        m_star = -20.26
+        alpha = -1.98
+        model = Schechter1D(phi_star, m_star, alpha)
+        mag = np.linspace(-25, -17)
+
+        fig, ax = plt.subplots()
+        ax.plot(mag, model(mag))
+        ax.set_yscale('log')
+        ax.set_xlim(-22.6, -17)
+        ax.set_ylim(1.e-7, 1.e-2)
+        ax.set_xlabel('$M_{UV}$')
+        ax.set_ylabel('$\phi$ [mag$^{-1}$ Mpc$^{-3}]$')
+
+    References
+    ----------
+    .. [1] Schechter 1976; ApJ 203, 297
+           (https://ui.adsabs.harvard.edu/abs/1976ApJ...203..297S/abstract)
+
+    .. [2] `Luminosity function <https://en.wikipedia.org/wiki/Luminosity_function_(astronomy)>`_
+    """
+
+    phi_star = Parameter(default=1., description=('Normalization factor '
+                                                  'in units of number density'))
+    m_star = Parameter(default=-20., description='Characteristic magnitude', mag=True)
+    alpha = Parameter(default=-1., description='Faint-end slope')
+
+    @staticmethod
+    def _factor(magnitude, m_star):
+        factor_exp = (magnitude - m_star)
+
+        if isinstance(factor_exp, Quantity):
+            if factor_exp.unit == mag:
+                factor_exp = Magnitude(factor_exp.value, unit=mag)
+
+                return factor_exp.to(dimensionless_unscaled)
+            else:
+                raise UnitsError("The units of magnitude and m_star must be a magnitude")
+        else:
+            return 10 ** (-0.4 * factor_exp)
+
+    def evaluate(self, mag, phi_star, m_star, alpha):
+        """Schechter luminosity function model function."""
+
+        factor = self._factor(mag, m_star)
+
+        return 0.4 * np.log(10) * phi_star * factor**(alpha + 1) * np.exp(-factor)
+
+    def fit_deriv(self, mag, phi_star, m_star, alpha):
+        """
+        Schechter luminosity function derivative with respect to
+        parameters.
+        """
+        factor = self._factor(mag, m_star)
+
+        d_phi_star = 0.4 * np.log(10) * factor**(alpha + 1) * np.exp(-factor)
+        func = phi_star * d_phi_star
+        d_m_star = ((alpha + 1) * 0.4 * np.log(10) * func
+                    - (0.4 * np.log(10) * func * factor))
+        d_alpha = func * np.log(factor)
+
+        return [d_phi_star, d_m_star, d_alpha]
+
+    @property
+    def input_units(self):
+        if self.m_star.unit is None:
+            return None
+        return {self.inputs[0]: self.m_star.unit}
+
+    def _parameter_units_for_data_units(self, inputs_unit, outputs_unit):
+        return {'m_star': inputs_unit[self.inputs[0]],
+                'phi_star': outputs_unit[self.outputs[0]]}
