@@ -42,6 +42,7 @@ def _possible_string_format_functions(format_):
     yield lambda format_, val: format(val, format_)
     yield lambda format_, val: format_.format(val)
     yield lambda format_, val: format_ % val
+    yield lambda format_, val: format_.format(**{k: val[k] for k in val.dtype.names})
 
 
 def get_auto_format_func(
@@ -270,7 +271,9 @@ class TableFormatter:
                                                show_length=show_length,
                                                outs=outs)
 
-        col_strs = list(col_strs_iter)
+        # Replace tab and newline with text representations so they display nicely.
+        # Newline in particular is a problem in a multicolumn table.
+        col_strs = [val.replace('\t', '\\t').replace('\n', '\\n') for val in col_strs_iter]
         if len(col_strs) > 0:
             col_width = max(len(x) for x in col_strs)
 
@@ -341,6 +344,20 @@ class TableFormatter:
 
         return col_strs, outs
 
+    def _name_and_structure(self, name, dtype, sep=" "):
+        """Format a column name, including a possible structure.
+
+        Normally, just returns the name, but if it has a structured dtype,
+        will add the parts in between square brackets.  E.g.,
+        "name [f0, f1]" or "name [f0[sf0, sf1], f1]".
+        """
+        if dtype is None or dtype.names is None:
+            return name
+
+        structure = ', '.join([self._name_and_structure(name, dt, sep="")
+                               for name, (dt, _) in dtype.fields.items()])
+        return f"{name}{sep}[{structure}]"
+
     def _pformat_col_iter(self, col, max_lines, show_name, show_unit, outs,
                           show_dtype=False, show_length=None):
         """Iterator which yields formatted string representation of column values.
@@ -370,12 +387,13 @@ class TableFormatter:
             if the column is not shown completely.
         """
         max_lines, _ = self._get_pprint_size(max_lines, -1)
-
+        dtype = getattr(col, 'dtype', None)
         multidims = getattr(col, 'shape', [0])[1:]
         if multidims:
             multidim0 = tuple(0 for n in multidims)
             multidim1 = tuple(n - 1 for n in multidims)
-            trivial_multidims = np.prod(multidims) == 1
+            multidims_all_ones = np.prod(multidims) == 1
+            multidims_has_zero = 0 in multidims
 
         i_dashes = None
         i_centers = []  # Line indexes where content should be centered
@@ -384,10 +402,8 @@ class TableFormatter:
             i_centers.append(n_header)
             # Get column name (or 'None' if not set)
             col_name = str(col.info.name)
-            if multidims:
-                col_name += f" [{','.join(str(n) for n in multidims)}]"
             n_header += 1
-            yield col_name
+            yield self._name_and_structure(col_name, dtype)
         if show_unit:
             i_centers.append(n_header)
             n_header += 1
@@ -395,11 +411,11 @@ class TableFormatter:
         if show_dtype:
             i_centers.append(n_header)
             n_header += 1
-            try:
-                dtype = dtype_info_name(col.dtype)
-            except AttributeError:
-                dtype = col.__class__.__qualname__ or 'object'
-            yield str(dtype)
+            if dtype is not None:
+                col_dtype = dtype_info_name((dtype, multidims))
+            else:
+                col_dtype = col.__class__.__qualname__ or 'object'
+            yield col_dtype
         if show_unit or show_name or show_dtype:
             i_dashes = n_header
             n_header += 1
@@ -460,8 +476,11 @@ class TableFormatter:
                 # Prevents columns like Column(data=[[(1,)],[(2,)]], name='a')
                 # with shape (n,1,...,1) from being printed as if there was
                 # more than one element in a row
-                if trivial_multidims:
+                if multidims_all_ones:
                     return format_func(col_format, col[(idx,) + multidim0])
+                elif multidims_has_zero:
+                    # Any zero dimension means there is no data to print
+                    return ""
                 else:
                     left = format_func(col_format, col[(idx,) + multidim0])
                     right = format_func(col_format, col[(idx,) + multidim1])
@@ -510,7 +529,7 @@ class TableFormatter:
             for the unit.
 
         show_dtype : bool
-            Include a header row for column dtypes. Default is False.
+            Include a header row for column dtypes. Default is to False.
 
         html : bool
             Format the output as an HTML table. Default is False.
