@@ -3,6 +3,7 @@
 
 from astropy.utils.tests.test_metadata import MetaBaseTest
 import operator
+import warnings
 
 import pytest
 import numpy as np
@@ -757,7 +758,6 @@ def test_col_unicode_sandwich_unicode():
     """
     Sanity check that Unicode Column behaves normally.
     """
-    # On Py2 the unicode must be ASCII-compatible, else the final test fails.
     uba = 'bä'
     uba8 = uba.encode('utf-8')
 
@@ -775,7 +775,10 @@ def test_col_unicode_sandwich_unicode():
     assert ok.dtype.char == '?'
     assert np.all(ok)
 
-    assert np.all(c != [uba8, b'def'])
+    with warnings.catch_warnings():
+        # Ignore the FutureWarning in numpy >=1.24 (it is OK).
+        warnings.filterwarnings('ignore', message='.*elementwise comparison failed.*')
+        assert np.all(c != [uba8, b'def'])
 
 
 def test_masked_col_unicode_sandwich():
@@ -934,3 +937,23 @@ def test_masked_column_serialize_method_propagation():
     assert mc4.info.serialize_method['ecsv'] == 'data_mask'
     mc5 = mc[1:]
     assert mc5.info.serialize_method['ecsv'] == 'data_mask'
+
+
+@pytest.mark.parametrize('dtype', ['S', 'U', 'i'])
+def test_searchsorted(Column, dtype):
+    c = Column([1, 2, 2, 3], dtype=dtype)
+    if isinstance(Column, table.MaskedColumn):
+        # Searchsorted seems to ignore the mask
+        c[2] = np.ma.masked
+
+    if dtype == 'i':
+        vs = (2, [2, 1])
+    else:
+        vs = ('2', ['2', '1'], b'2', [b'2', b'1'])
+    for v in vs:
+        v = np.array(v, dtype=dtype)
+        exp = np.searchsorted(c.data, v, side='right')
+        res = c.searchsorted(v, side='right')
+        assert np.all(res == exp)
+        res = np.searchsorted(c, v, side='right')
+        assert np.all(res == exp)
