@@ -23,7 +23,7 @@ from astropy.table import table_helpers
 from astropy.utils.exceptions import AstropyUserWarning
 from astropy.utils.metadata import MergeConflictWarning
 from astropy.coordinates.tests.test_representation import representation_equal
-from astropy.io.misc.asdf.tags.helpers import skycoord_equal
+from astropy.coordinates.tests.helper import skycoord_equal
 
 from .conftest import MIXIN_COLS
 
@@ -441,38 +441,76 @@ def test_info_preserved_pickle_copy_init(mixin_cols):
                 assert getattr(m2.info, attr) == original
 
 
-def test_add_column(mixin_cols):
+def check_share_memory(col1, col2, copy):
+    """Check whether data attributes in col1 and col2 share memory.
+
+    If copy=True, this should not be the case for any, while
+    if copy=False, all should share memory.
     """
-    Test that adding a column preserves values and attributes
+    if isinstance(col1, SkyCoord):
+        # For SkyCoord, .info does not access actual data by default,
+        # but rather attributes like .ra, which are copies.
+        map1 = col1.data.info._represent_as_dict()
+        map2 = col2.data.info._represent_as_dict()
+    else:
+        map1 = col1.info._represent_as_dict()
+        map2 = col2.info._represent_as_dict()
+
+    # Check array attributes only (in principle, could iterate on, e.g.,
+    # differentials in representations, but this is enough for table).
+    shared = [np.may_share_memory(v1, v2)
+              for (v1, v2) in zip(map1.values(), map2.values())
+              if isinstance(v1, np.ndarray) and v1.shape]
+    if copy:
+        assert not any(shared)
+    else:
+        assert all(shared)
+
+
+@pytest.mark.parametrize('copy', [True, False])
+def test_add_column(mixin_cols, copy):
+    """
+    Test that adding a column preserves values and attributes.
+    For copy=True, the data should be independent;
+    for copy=False, the data should be shared, but the instance independent.
     """
     attrs = ('name', 'unit', 'dtype', 'format', 'description', 'meta')
     m = mixin_cols['m']
     assert m.info.name is None
 
-    # Make sure adding column in various ways doesn't touch
-    t = QTable([m], names=['a'])
+    # Make sure adding column in various ways doesn't touch info.
+    t = QTable([m], names=['a'], copy=copy)
     assert m.info.name is None
+    check_share_memory(m, t['a'], copy=copy)
 
     t['new'] = m
     assert m.info.name is None
+    check_share_memory(m, t['new'], copy=True)
 
     m.info.name = 'm'
     m.info.format = '{0}'
     m.info.description = 'd'
     m.info.meta = {'a': 1}
-    t = QTable([m])
+    t = QTable([m], copy=copy)
+    assert t.colnames == ['m']
+    check_share_memory(m, t['m'], copy=copy)
+
+    t = QTable([m], names=['m1'], copy=copy)
+    assert m.info.name == 'm'
+    assert t.colnames == ['m1']
+    check_share_memory(m, t['m1'], copy=copy)
 
     # Add columns m2, m3, m4 by two different methods and test expected equality
     t['m2'] = m
+    check_share_memory(m, t['m2'], copy=True)
     m.info.name = 'm3'
-    t.add_columns([m], copy=True)
-    m.info.name = 'm4'
-    t.add_columns([m], copy=False)
-    for name in ('m2', 'm3', 'm4'):
+    t.add_columns([m], copy=copy)
+    check_share_memory(m, t['m3'], copy=copy)
+    for name in ('m2', 'm3'):
         assert_table_name_col_equal(t, name, m)
         for attr in attrs:
             if attr != 'name':
-                assert getattr(t['m'].info, attr) == getattr(t[name].info, attr)
+                assert getattr(t['m1'].info, attr) == getattr(t[name].info, attr)
     # Also check that one can set using a scalar.
     s = m[0]
     if type(s) is type(m) and 'info' in s.__dict__:
@@ -480,18 +518,20 @@ def test_add_column(mixin_cols):
         # are a different class than the real array, or where info is not copied.
         t['s'] = m[0]
         assert_table_name_col_equal(t, 's', m[0])
+        check_share_memory(m, t['s'], copy=True)
         for attr in attrs:
             if attr != 'name':
-                assert getattr(t['m'].info, attr) == getattr(t['s'].info, attr)
+                assert getattr(t['m1'].info, attr) == getattr(t['s'].info, attr)
 
     # While we're add it, also check a length-1 table.
-    t = QTable([m[1:2]], names=['m'])
+    t = QTable([m[1:2]], names=['m'], copy=copy)
+    check_share_memory(m, t['m'], copy=copy)
     if type(s) is type(m) and 'info' in s.__dict__:
         t['s'] = m[0]
         assert_table_name_col_equal(t, 's', m[0])
         for attr in attrs:
             if attr != 'name':
-                assert getattr(t['m'].info, attr) == getattr(t['s'].info, attr)
+                assert getattr(t['m1'].info, attr) == getattr(t['s'].info, attr)
 
 
 def test_vstack():
@@ -697,19 +737,30 @@ def test_skycoord_representation():
                            '1.0,90.0,0.0']
 
 
-def test_ndarray_mixin():
+@pytest.mark.parametrize('as_ndarray_mixin', [True, False])
+def test_ndarray_mixin(as_ndarray_mixin):
     """
-    Test directly adding a plain structured array into a table instead of the
-    view as an NdarrayMixin.  Once added as an NdarrayMixin then all the previous
-    tests apply.
+    Test directly adding various forms of structured ndarray columns to a table.
+    Adding as NdarrayMixin is expected to be somewhat unusual after #12644
+    (which provides full support for structured array Column's). This test shows
+    that the end behavior is the same in both cases.
     """
     a = np.array([(1, 'a'), (2, 'b'), (3, 'c'), (4, 'd')],
                  dtype='<i4,' + ('|U1'))
     b = np.array([(10, 'aa'), (20, 'bb'), (30, 'cc'), (40, 'dd')],
                  dtype=[('x', 'i4'), ('y', ('U2'))])
-    c = np.rec.fromrecords([(100, 'raa'), (200, 'rbb'), (300, 'rcc'), (400, 'rdd')],
+    c = np.rec.fromrecords([(100., 'raa'), (200., 'rbb'), (300., 'rcc'), (400., 'rdd')],
                            names=['rx', 'ry'])
-    d = np.arange(8).reshape(4, 2).view(NdarrayMixin)
+    d = np.arange(8, dtype='i8').reshape(4, 2)
+
+    if as_ndarray_mixin:
+        a = a.view(NdarrayMixin)
+        b = b.view(NdarrayMixin)
+        c = c.view(NdarrayMixin)
+        d = d.view(NdarrayMixin)
+        class_exp = NdarrayMixin
+    else:
+        class_exp = Column
 
     # Add one during initialization and the next as a new column.
     t = Table([a], names=['a'])
@@ -717,7 +768,7 @@ def test_ndarray_mixin():
     t['c'] = c
     t['d'] = d
 
-    assert isinstance(t['a'], NdarrayMixin)
+    assert isinstance(t['a'], class_exp)
 
     assert t['a'][1][1] == a[1][1]
     assert t['a'][2][0] == a[2][0]
@@ -725,7 +776,7 @@ def test_ndarray_mixin():
     assert t[1]['a'][1] == a[1][1]
     assert t[2]['a'][0] == a[2][0]
 
-    assert isinstance(t['b'], NdarrayMixin)
+    assert isinstance(t['b'], class_exp)
 
     assert t['b'][1]['x'] == b[1]['x']
     assert t['b'][1]['y'] == b[1]['y']
@@ -733,7 +784,7 @@ def test_ndarray_mixin():
     assert t[1]['b']['x'] == b[1]['x']
     assert t[1]['b']['y'] == b[1]['y']
 
-    assert isinstance(t['c'], NdarrayMixin)
+    assert isinstance(t['c'], class_exp)
 
     assert t['c'][1]['rx'] == c[1]['rx']
     assert t['c'][1]['ry'] == c[1]['ry']
@@ -741,7 +792,7 @@ def test_ndarray_mixin():
     assert t[1]['c']['rx'] == c[1]['rx']
     assert t[1]['c']['ry'] == c[1]['ry']
 
-    assert isinstance(t['d'], NdarrayMixin)
+    assert isinstance(t['d'], class_exp)
 
     assert t['d'][1][0] == d[1][0]
     assert t['d'][1][1] == d[1][1]
@@ -749,12 +800,14 @@ def test_ndarray_mixin():
     assert t[1]['d'][0] == d[1][0]
     assert t[1]['d'][1] == d[1][1]
 
-    assert t.pformat() == ['   a         b           c       d [2] ',
-                           '-------- ---------- ------------ ------',
-                           "(1, 'a') (10, 'aa') (100, 'raa') 0 .. 1",
-                           "(2, 'b') (20, 'bb') (200, 'rbb') 2 .. 3",
-                           "(3, 'c') (30, 'cc') (300, 'rcc') 4 .. 5",
-                           "(4, 'd') (40, 'dd') (400, 'rdd') 6 .. 7"]
+    assert t.pformat(show_dtype=True) == [
+        '  a [f0, f1]     b [x, y]      c [rx, ry]      d    ',
+        '(int32, str1) (int32, str2) (float64, str3) int64[2]',
+        '------------- ------------- --------------- --------',
+        "     (1, 'a')    (10, 'aa')   (100., 'raa')   0 .. 1",
+        "     (2, 'b')    (20, 'bb')   (200., 'rbb')   2 .. 3",
+        "     (3, 'c')    (30, 'cc')   (300., 'rcc')   4 .. 5",
+        "     (4, 'd')    (40, 'dd')   (400., 'rdd')   6 .. 7"]
 
 
 def test_possible_string_format_functions():
@@ -842,8 +895,9 @@ def test_skycoord_with_velocity():
     assert skycoord_equal(t2['col0'], sc)
 
 
+@pytest.mark.parametrize('copy', [True, False])
 @pytest.mark.parametrize('table_cls', [Table, QTable])
-def test_ensure_input_info_is_unchanged(table_cls):
+def test_ensure_input_info_is_unchanged(table_cls, copy):
     """If a mixin input to a table has no info, it should stay that way.
 
     This since having 'info' slows down slicing, etc.
@@ -851,11 +905,11 @@ def test_ensure_input_info_is_unchanged(table_cls):
     """
     q = [1, 2] * u.m
     assert 'info' not in q.__dict__
-    t = table_cls([q], names=['q'])
+    t = table_cls([q], names=['q'], copy=copy)
     assert 'info' not in q.__dict__
-    t = table_cls([q])
+    t = table_cls([q], copy=copy)
     assert 'info' not in q.__dict__
-    t = table_cls({'q': q})
+    t = table_cls({'q': q}, copy=copy)
     assert 'info' not in q.__dict__
     t['q2'] = q
     assert 'info' not in q.__dict__
