@@ -304,7 +304,7 @@ def test_pandas():
 def test_read_time_missing():
     with pytest.raises(ValueError) as exc:
         TimeSeries.read(CSV_FILE, format='csv')
-    assert exc.value.args[0] == '``time_column`` should be provided since the default Table readers are being used.'
+    assert exc.value.args[0] == '``time_column`` should be provided since the default Table readers are being used.'  # noqa: E501
 
 
 def test_read_time_wrong():
@@ -323,8 +323,13 @@ def test_read():
 
 @pytest.mark.remote_data(source='astropy')
 def test_kepler_astropy():
+    from astropy.units import UnitsWarning
+
     filename = get_pkg_data_filename('timeseries/kplr010666592-2009131110544_slc.fits')
-    timeseries = TimeSeries.read(filename, format='kepler.fits')
+
+    with pytest.warns(UnitsWarning):
+        timeseries = TimeSeries.read(filename, format='kepler.fits')
+
     assert timeseries["time"].format == 'isot'
     assert timeseries["time"].scale == 'tdb'
     assert timeseries["sap_flux"].unit.to_string() == 'electron / s'
@@ -334,7 +339,7 @@ def test_kepler_astropy():
 
 @pytest.mark.remote_data(source='astropy')
 def test_tess_astropy():
-    filename = get_pkg_data_filename('timeseries/hlsp_tess-data-alerts_tess_phot_00025155310-s01_tess_v1_lc.fits')
+    filename = get_pkg_data_filename('timeseries/hlsp_tess-data-alerts_tess_phot_00025155310-s01_tess_v1_lc.fits')  # noqa: E501
     with pytest.warns(UserWarning, match='Ignoring 815 rows with NaN times'):
         timeseries = TimeSeries.read(filename, format='tess.fits')
     assert timeseries["time"].format == 'isot'
@@ -390,6 +395,14 @@ def test_required_columns():
     assert exc.value.args[0] == ("TimeSeries object is invalid - expected "
                                  "'time' as the first column but found 'banana'")
 
+    # https://github.com/astropy/astropy/issues/13009
+    ts_2cols_required = ts.copy()
+    ts_2cols_required._required_columns = ['time', 'a']
+    with pytest.raises(ValueError) as exc:
+        ts_2cols_required.remove_column('a')
+    assert exc.value.args[0] == ("TimeSeries object is invalid - expected "
+                                 "['time', 'a'] as the first columns but found ['time', 'b']")
+
 
 @pytest.mark.parametrize('cls', [BoxLeastSquares, LombScargle])
 def test_periodogram(cls):
