@@ -6,35 +6,33 @@ associated units. `Quantity` objects support operations like ordinary numbers,
 but will deal with unit conversions internally.
 """
 
-
-# Standard library
-import re
+# STDLIB
 import numbers
-from fractions import Fraction
 import operator
+import re
 import warnings
+from fractions import Fraction
 
+# THIRD PARTY
 import numpy as np
 
-# AstroPy
-from .core import (Unit, dimensionless_unscaled, get_current_unit_registry,
-                   UnitBase, UnitsError, UnitConversionError, UnitTypeError)
+# LOCAL
+from astropy import config as _config
+from astropy.utils.compat import NUMPY_LT_1_20, NUMPY_LT_1_22
+from astropy.utils.compat.misc import override__dir__
+from astropy.utils.data_info import ParentDtypeInfo
+from astropy.utils.exceptions import AstropyDeprecationWarning, AstropyWarning
+from astropy.utils.misc import isiterable
+
+from .core import (
+    Unit, UnitBase, UnitConversionError, UnitsError, UnitTypeError, dimensionless_unscaled,
+    get_current_unit_registry)
+from .format.latex import Latex
+from .quantity_helper import can_have_arbitrary_unit, check_output, converters_and_unit
+from .quantity_helper.function_helpers import (
+    DISPATCHED_FUNCTIONS, FUNCTION_HELPERS, SUBCLASS_SAFE_FUNCTIONS, UNSUPPORTED_FUNCTIONS)
 from .structured import StructuredUnit
 from .utils import is_effectively_unity
-from .format.latex import Latex
-from astropy.utils.compat import NUMPY_LT_1_22
-from astropy.utils.compat.misc import override__dir__
-from astropy.utils.exceptions import AstropyDeprecationWarning, AstropyWarning
-from astropy.utils.introspection import minversion
-from astropy.utils.misc import isiterable
-from astropy.utils.data_info import ParentDtypeInfo
-from astropy import config as _config
-from .quantity_helper import (converters_and_unit, can_have_arbitrary_unit,
-                              check_output)
-from .quantity_helper.function_helpers import (
-    SUBCLASS_SAFE_FUNCTIONS, FUNCTION_HELPERS, DISPATCHED_FUNCTIONS,
-    UNSUPPORTED_FUNCTIONS)
-
 
 __all__ = ["Quantity", "SpecificTypeQuantity",
            "QuantityInfoBase", "QuantityInfo", "allclose", "isclose"]
@@ -603,6 +601,15 @@ class Quantity(np.ndarray):
             # Ensure output argument remains a tuple.
             kwargs['out'] = (out_array,) if function.nout == 1 else out_array
 
+        if method == 'reduce' and 'initial' in kwargs and unit is not None:
+            # Special-case for initial argument for reductions like
+            # np.add.reduce.  This should be converted to the output unit as
+            # well, which is typically the same as the input unit (but can
+            # in principle be different: unitless for np.equal, radian
+            # for np.arctan2, though those are not necessarily useful!)
+            kwargs['initial'] = self._to_own_unit(kwargs['initial'],
+                                                  check_precision=False, unit=unit)
+
         # Same for inputs, but here also convert if necessary.
         arrays = []
         for input_, converter in zip(inputs, converters):
@@ -1166,18 +1173,6 @@ class Quantity(np.ndarray):
 
         return super().__rtruediv__(other)
 
-    def __div__(self, other):
-        """ Division between `Quantity` objects. """
-        return self.__truediv__(other)
-
-    def __idiv__(self, other):
-        """ Division between `Quantity` objects. """
-        return self.__itruediv__(other)
-
-    def __rdiv__(self, other):
-        """ Division between `Quantity` objects. """
-        return self.__rtruediv__(other)
-
     def __pow__(self, other):
         if isinstance(other, Fraction):
             # Avoid getting object arrays by raising the value to a Fraction.
@@ -1321,9 +1316,13 @@ class Quantity(np.ndarray):
 
             - 'latex': Return a LaTeX-formatted string
 
+            - 'latex_inline': Return a LaTeX-formatted string that uses
+              negative exponents instead of fractions
+
         subfmt : str, optional
-            Subformat of the result. For the moment,
-            only used for format="latex". Supported values are:
+            Subformat of the result. For the moment, only used for
+            ``format='latex'`` and ``format='latex_inline'``. Supported
+            values are:
 
             - 'inline': Use ``$ ... $`` as delimiters.
 
@@ -1346,6 +1345,7 @@ class Quantity(np.ndarray):
                 "display": (r"$\displaystyle ", r"$"),
             },
         }
+        formats['latex_inline'] = formats['latex']
 
         if format not in formats:
             raise ValueError(f"Unknown format '{format}'")
@@ -1355,12 +1355,10 @@ class Quantity(np.ndarray):
                 return f'{self.value}{self._unitstr:s}'
             else:
                 # np.array2string properly formats arrays as well as scalars
-                return np.array2string(self.value, precision=precision, floatmode="fixed") + self._unitstr
+                return np.array2string(self.value, precision=precision,
+                                       floatmode="fixed") + self._unitstr
 
-        # else, for the moment we assume format="latex"
-
-        # need to do try/finally because "threshold" cannot be overridden
-        # with array2string
+        # else, for the moment we assume format="latex" or "latex_inline".
 
         # Set the precision if set, otherwise use numpy default
         pops = np.get_printoptions()
@@ -1377,32 +1375,30 @@ class Quantity(np.ndarray):
                 Latex.format_exponential_notation(value.imag,
                                                   format_spec='+' + format_spec))
 
-        try:
-            formatter = {'float_kind': float_formatter,
-                         'complex_kind': complex_formatter}
-            if conf.latex_array_threshold > -1:
-                np.set_printoptions(threshold=conf.latex_array_threshold)
+        # The view is needed for the scalar case - self.value might be float.
+        latex_value = np.array2string(
+            self.view(np.ndarray),
+            threshold=(conf.latex_array_threshold
+                       if conf.latex_array_threshold > -1 else pops['threshold']),
+            formatter={'float_kind': float_formatter,
+                       'complex_kind': complex_formatter},
+            max_line_width=np.inf,
+            separator=',~')
 
-            # the view is needed for the scalar case - value might be float
-            latex_value = np.array2string(
-                self.view(np.ndarray),
-                formatter=formatter, max_line_width=np.inf, separator=',~')
-
-            latex_value = latex_value.replace('...', r'\dots')
-        finally:
-            np.set_printoptions(**pops)
+        latex_value = latex_value.replace('...', r'\dots')
 
         # Format unit
         # [1:-1] strips the '$' on either side needed for math mode
-        latex_unit = (self.unit._repr_latex_()[1:-1]  # note this is unicode
-                      if self.unit is not None
-                      else _UNIT_NOT_INITIALISED)
+        if self.unit is None:
+            latex_unit = _UNIT_NOT_INITIALISED
+        elif format == 'latex':
+            latex_unit = self.unit._repr_latex_()[1:-1] # note this is unicode
+        elif format == 'latex_inline':
+            latex_unit = self.unit.to_string(format='latex_inline')[1:-1]
 
         delimiter_left, delimiter_right = formats[format][subfmt]
 
-        return r'{left}{0} \; {1}{right}'.format(latex_value, latex_unit,
-                                                 left=delimiter_left,
-                                                 right=delimiter_right)
+        return rf'{delimiter_left}{latex_value} \; {latex_unit}{delimiter_right}'
 
     def __str__(self):
         return self.to_string()
@@ -1522,9 +1518,32 @@ class Quantity(np.ndarray):
         raise NotImplementedError("cannot make a list of Quantities.  Get "
                                   "list of values with q.value.tolist()")
 
-    def _to_own_unit(self, value, check_precision=True):
+    def _to_own_unit(self, value, check_precision=True, *, unit=None):
+        """Convert value to one's own unit (or that given).
+
+        Here, non-quantities are treated as dimensionless, and care is taken
+        for values of 0, infinity or nan, which are allowed to have any unit.
+
+        Parameters
+        ----------
+        value : anything convertible to `~astropy.units.Quantity`
+            The value to be converted to the requested unit.
+        check_precision : bool
+            Whether to forbit conversion of float to integer if that changes
+            the input number.  Default: `True`.
+        unit : `~astropy.units.Unit` or None
+            The unit to convert to.  By default, the unit of ``self``.
+
+        Returns
+        -------
+        value : number or `~numpy.ndarray`
+            In the requested units.
+
+        """
+        if unit is None:
+            unit = self.unit
         try:
-            _value = value.to_value(self.unit)
+            _value = value.to_value(unit)
         except AttributeError:
             # We're not a Quantity.
             # First remove two special cases (with a fast test):
@@ -1540,7 +1559,7 @@ class Quantity(np.ndarray):
             # but anything with a unit attribute will use that.
             try:
                 as_quantity = Quantity(value)
-                _value = as_quantity.to_value(self.unit)
+                _value = as_quantity.to_value(unit)
             except UnitsError:
                 # last chance: if this was not something with a unit
                 # and is all 0, inf, or nan, we treat it as arbitrary unit.
@@ -1802,19 +1821,34 @@ class Quantity(np.ndarray):
     def trace(self, offset=0, axis1=0, axis2=1, dtype=None, out=None):
         return self._wrap_function(np.trace, offset, axis1, axis2, dtype,
                                    out=out)
+    if NUMPY_LT_1_20:
+        def var(self, axis=None, dtype=None, out=None, ddof=0, keepdims=False):
+            return self._wrap_function(np.var, axis, dtype,
+                                       out=out, ddof=ddof, keepdims=keepdims,
+                                       unit=self.unit**2)
+    else:
+        def var(self, axis=None, dtype=None, out=None, ddof=0, keepdims=False, *, where=True):
+            return self._wrap_function(np.var, axis, dtype,
+                                       out=out, ddof=ddof, keepdims=keepdims, where=where,
+                                       unit=self.unit**2)
 
-    def var(self, axis=None, dtype=None, out=None, ddof=0, keepdims=False):
-        return self._wrap_function(np.var, axis, dtype,
-                                   out=out, ddof=ddof, keepdims=keepdims,
-                                   unit=self.unit**2)
+    if NUMPY_LT_1_20:
+        def std(self, axis=None, dtype=None, out=None, ddof=0, keepdims=False):
+            return self._wrap_function(np.std, axis, dtype, out=out, ddof=ddof,
+                                       keepdims=keepdims)
+    else:
+        def std(self, axis=None, dtype=None, out=None, ddof=0, keepdims=False, *, where=True):
+            return self._wrap_function(np.std, axis, dtype, out=out, ddof=ddof,
+                                       keepdims=keepdims, where=where)
 
-    def std(self, axis=None, dtype=None, out=None, ddof=0, keepdims=False):
-        return self._wrap_function(np.std, axis, dtype, out=out, ddof=ddof,
-                                   keepdims=keepdims)
-
-    def mean(self, axis=None, dtype=None, out=None, keepdims=False):
-        return self._wrap_function(np.mean, axis, dtype, out=out,
-                                   keepdims=keepdims)
+    if NUMPY_LT_1_20:
+        def mean(self, axis=None, dtype=None, out=None, keepdims=False):
+            return self._wrap_function(np.mean, axis, dtype, out=out,
+                                       keepdims=keepdims)
+    else:
+        def mean(self, axis=None, dtype=None, out=None, keepdims=False, *, where=True):
+            return self._wrap_function(np.mean, axis, dtype, out=out,
+                                       keepdims=keepdims, where=where)
 
     def round(self, decimals=0, out=None):
         return self._wrap_function(np.round, decimals, out=out)
@@ -1841,9 +1875,18 @@ class Quantity(np.ndarray):
     def ediff1d(self, to_end=None, to_begin=None):
         return self._wrap_function(np.ediff1d, to_end, to_begin)
 
-    def nansum(self, axis=None, out=None, keepdims=False):
-        return self._wrap_function(np.nansum, axis,
-                                   out=out, keepdims=keepdims)
+    if NUMPY_LT_1_22:
+        def nansum(self, axis=None, out=None, keepdims=False):
+            return self._wrap_function(np.nansum, axis,
+                                       out=out, keepdims=keepdims)
+    else:
+        # TODO: deprecate this method? It is not on ndarray, and we do not
+        # support nanmean, etc., so why this one?
+        def nansum(self, axis=None, out=None, keepdims=False, *, initial=None, where=True):
+            if initial is not None:
+                initial = self._to_own_unit(initial)
+            return self._wrap_function(np.nansum, axis,
+                                       out=out, keepdims=keepdims, initial=initial, where=where)
 
     def insert(self, obj, values, axis=None):
         """
