@@ -1,19 +1,18 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-import itertools
 import inspect
+import itertools
 
 import numpy as np
-from numpy.testing import assert_array_equal
-
+import numpy.lib.recfunctions as rfn
 import pytest
+from numpy.testing import assert_array_equal
 
 from astropy import units as u
 from astropy.units.quantity_helper.function_helpers import (
-    ARRAY_FUNCTION_ENABLED, SUBCLASS_SAFE_FUNCTIONS, UNSUPPORTED_FUNCTIONS,
-    FUNCTION_HELPERS, DISPATCHED_FUNCTIONS, IGNORED_FUNCTIONS)
+    ARRAY_FUNCTION_ENABLED, DISPATCHED_FUNCTIONS, FUNCTION_HELPERS, IGNORED_FUNCTIONS,
+    SUBCLASS_SAFE_FUNCTIONS, TBD_FUNCTIONS, UNSUPPORTED_FUNCTIONS)
 from astropy.utils.compat import NUMPY_LT_1_20, NUMPY_LT_1_23
 
-
 needs_array_function = pytest.mark.xfail(
     not ARRAY_FUNCTION_ENABLED,
     reason="Needs __array_function__ support")
@@ -25,14 +24,14 @@ def get_wrapped_functions(*modules):
     wrapped_functions = {}
     for mod in modules:
         for name, f in mod.__dict__.items():
-            if f is np.printoptions:
+            if f is np.printoptions or name.startswith('_'):
                 continue
             if callable(f) and hasattr(f, '__wrapped__'):
                 wrapped_functions[name] = f
     return wrapped_functions
 
 
-all_wrapped_functions = get_wrapped_functions(np, np.fft, np.linalg)
+all_wrapped_functions = get_wrapped_functions(np, np.fft, np.linalg, np.lib.recfunctions)
 all_wrapped = set(all_wrapped_functions.values())
 
 
@@ -461,6 +460,10 @@ class TestConcatenate(metaclass=CoverageMeta):
     def test_concatenate(self):
         self.check(np.concatenate)
         self.check(np.concatenate, axis=1)
+        if not NUMPY_LT_1_20:
+            # dtype argument only introduced in numpy 1.20
+            # regression test for gh-13322.
+            self.check(np.concatenate, dtype='f4')
 
         self.check(np.concatenate, q_list=[np.zeros(self.q1.shape), self.q1, self.q2],
                    q_ref=self.q1)
@@ -2033,6 +2036,53 @@ class TestLinAlg(metaclass=CoverageMeta):
         assert_array_equal(w, wx)
 
 
+class TestRecFunctions(metaclass=CoverageMeta):
+
+    def test_structured_to_unstructured(self):
+        # can't unstructure something with incompatible units
+        with pytest.raises(u.UnitConversionError, match="'m'"):
+            rfn.structured_to_unstructured(u.Quantity((0, 0.6), u.Unit("(eV, m)")))
+
+        # it works if all the units are equal
+        struct = u.Quantity((0, 0, 0.6), u.Unit("(eV, eV, eV)"))
+        unstruct = rfn.structured_to_unstructured(struct)
+        assert_array_equal(unstruct, [0, 0, 0.6] * u.eV)
+
+        # also if the units are convertible
+        struct = u.Quantity((0, 0, 0.6), u.Unit("(eV, eV, keV)"))
+        unstruct = rfn.structured_to_unstructured(struct)
+        assert_array_equal(unstruct, [0, 0, 600] * u.eV)
+
+        struct = u.Quantity((0, 0, 1.7827e-33), u.Unit("(eV, eV, g)"))
+        with u.add_enabled_equivalencies(u.mass_energy()):
+            unstruct = rfn.structured_to_unstructured(struct)
+        u.allclose(unstruct, [0, 0, 1.0000214] * u.eV)
+
+        # and if the dtype is nested
+        struct = [(5, (400.0, 3e6))] * u.Unit('m, (cm, um)')
+        unstruct = rfn.structured_to_unstructured(struct)
+        assert_array_equal(unstruct, [[5, 4, 3]] * u.m)
+
+        # For the other tests of ``structured_to_unstructured``, see
+        # ``test_structured.TestStructuredQuantityFunctions.test_structured_to_unstructured``
+
+    def test_unstructured_to_structured(self):
+        unstruct = [1, 2, 3] * u.m
+        dtype=np.dtype([("f1", float), ("f2", float), ("f3", float)])
+
+        # it works
+        struct = rfn.unstructured_to_structured(unstruct, dtype=dtype)
+        assert struct.unit == u.Unit("(m, m, m)")
+        assert_array_equal(rfn.structured_to_unstructured(struct), unstruct)
+
+        # can't structure something that's already structured
+        with pytest.raises(ValueError, match="arr must have at least one dimension"):
+            rfn.unstructured_to_structured(struct, dtype=dtype)
+
+        # For the other tests of ``structured_to_unstructured``, see
+        # ``test_structured.TestStructuredQuantityFunctions.test_unstructured_to_structured``
+
+
 untested_functions = set()
 if NUMPY_LT_1_20:
     financial_functions = {f for f in all_wrapped_functions.values()
@@ -2057,6 +2107,15 @@ poly_functions = {
     }
 untested_functions |= poly_functions
 
+rec_functions = {
+    rfn.rec_append_fields, rfn.rec_drop_fields, rfn.rec_join,
+    rfn.drop_fields, rfn.rename_fields, rfn.append_fields, rfn.join_by,
+    rfn.repack_fields, rfn.apply_along_fields, rfn.assign_fields_by_name,
+    rfn.merge_arrays, rfn.stack_arrays, rfn.find_duplicates,
+    rfn.recursive_fill_fields, rfn.require_fields,
+}
+untested_functions |= rec_functions
+
 
 @needs_array_function
 def test_testing_completeness():
@@ -2084,4 +2143,4 @@ class TestFunctionHelpersCompleteness:
     # untested_function is created using all_wrapped_functions
     @needs_array_function
     def test_ignored_are_untested(self):
-        assert IGNORED_FUNCTIONS == untested_functions
+        assert IGNORED_FUNCTIONS | TBD_FUNCTIONS == untested_functions
