@@ -408,7 +408,7 @@ class CoordinateHelper:
             Distance in points between tick and label.
         exclude_overlapping : bool, optional
             Whether to exclude tick labels that overlap over each other.
-        kwargs
+        **kwargs
             Other keyword arguments are passed to :class:`matplotlib.text.Text`.
         """
         if size is not None:
@@ -457,7 +457,7 @@ class CoordinateHelper:
             The axis label text.
         minpad : float, optional
             The padding for the label in terms of axis label font size.
-        kwargs
+        **kwargs
             Keywords are passed to :class:`matplotlib.text.Text`. These
             can include keywords to set the ``color``, ``size``, ``weight``, and
             other text properties.
@@ -652,7 +652,7 @@ class CoordinateHelper:
         # Look up parent axes' transform from data to figure coordinates.
         #
         # See:
-        # https://matplotlib.org/users/transforms_tutorial.html#the-transformation-pipeline
+        # https://matplotlib.org/stable/tutorials/advanced/transforms_tutorial.html#the-transformation-pipeline
         transData = self.parent_axes.transData
         invertedTransLimits = transData.inverted()
 
@@ -785,8 +785,6 @@ class CoordinateHelper:
                     frac = (t - w1[imin]) / (w2[imin] - w1[imin])
                     x_data_i = spine.data[imin, 0] + frac * (spine.data[imax, 0] - spine.data[imin, 0])
                     y_data_i = spine.data[imin, 1] + frac * (spine.data[imax, 1] - spine.data[imin, 1])
-                    x_pix_i = spine.pixel[imin, 0] + frac * (spine.pixel[imax, 0] - spine.pixel[imin, 0])
-                    y_pix_i = spine.pixel[imin, 1] + frac * (spine.pixel[imax, 1] - spine.pixel[imin, 1])
                     delta_angle = tick_angle[imax] - tick_angle[imin]
                     if delta_angle > 180.:
                         delta_angle -= 360.
@@ -819,7 +817,7 @@ class CoordinateHelper:
                     # it's faster to format many ticklabels at once outside
                     # of the loop
                     self.lblinfo.append(dict(axis=axis,
-                                             pixel=(x_pix_i, y_pix_i),
+                                             data=(x_data_i, y_data_i),
                                              world=world,
                                              angle=spine.normal_angle[imin],
                                              axis_displacement=imin + frac))
