@@ -19,7 +19,7 @@ from astropy.io.fits import Header
 from astropy.io.fits.verify import VerifyWarning
 from astropy.units.core import UnitsWarning
 from astropy.utils.data import get_pkg_data_filename
-from astropy.wcs.wcs import WCS, FITSFixedWarning
+from astropy.wcs.wcs import WCS, FITSFixedWarning, Sip, NoConvergence
 from astropy.wcs.wcsapi.fitswcs import custom_ctype_to_ucd_mapping, VELOCITY_FRAMES
 from astropy.wcs._wcs import __version__ as wcsver
 from astropy.utils import iers
@@ -401,7 +401,7 @@ CTYPE3A = 'TT' / alternative linear time (TT)
 CRVAL3A = 2440.525 / Relative time of first frame
 CUNIT3A = 's' / Time unit
 CRPIX3A = 1.0 / Pixel coordinate at ref point
-OBSGEO-B= -24.6157 / [deg] Tel geodetic latitude (=North)+
+OBSGEO-B= -24.6157 / [deg] Tel geodetic latitute (=North)+
 OBSGEO-L= -70.3976 / [deg] Tel geodetic longitude (=East)+
 OBSGEO-H= 2530.0000 / [m] Tel height above reference ellipsoid
 CRDER3  = 0.0819 / random error in timings from fit
@@ -990,7 +990,7 @@ def test_spectralcoord_frame(header_spectral_frames):
 
     with iers.conf.set_temp('auto_download', False):
 
-        obstime = Time(f"2009-05-04T04:44:23", scale='utc')
+        obstime = Time("2009-05-04T04:44:23", scale='utc')
 
         header = header_spectral_frames.copy()
         header['MJD-OBS'] = obstime.mjd
@@ -1066,4 +1066,210 @@ def test_different_ctypes(header_spectral_frames, ctype3, observer):
         with pytest.warns(AstropyUserWarning, match='No observer defined on WCS'):
             pix = wcs.world_to_pixel(skycoord, spectralcoord)
 
-    assert_allclose(pix, [0, 0, 31], rtol=1e-6)
+    assert_allclose(pix, [0, 0, 31], rtol=1e-6, atol=1e-9)
+
+
+def test_non_convergence_warning():
+    """Test case for issue #11446
+    Since we can't define a target accuracy when plotting a WCS `all_world2pix`
+    should not error but only warn when the default accuracy can't be reached.
+    """
+    # define a minimal WCS where convergence fails for certain image positions
+    wcs = WCS(naxis=2)
+    crpix = [0, 0]
+    a = b = ap = bp = np.zeros((4, 4))
+    a[3, 0] = -1.20116753e-07
+
+    test_pos_x = [1000, 1]
+    test_pos_y = [0, 2]
+
+    wcs.sip = Sip(a, b, ap, bp, crpix)
+    # first make sure the WCS works when using a low accuracy
+    expected = wcs.all_world2pix(test_pos_x, test_pos_y, 0, tolerance=1e-3)
+
+    # then check that it fails when using the default accuracy
+    with pytest.raises(NoConvergence):
+        wcs.all_world2pix(test_pos_x, test_pos_y, 0)
+
+    # at last check that world_to_pixel_values raises a warning but returns
+    # the same 'low accuray' result
+    with pytest.warns(UserWarning):
+        assert_allclose(wcs.world_to_pixel_values(test_pos_x, test_pos_y),
+                        expected)
+
+
+HEADER_SPECTRAL_1D = """
+CTYPE1  = 'FREQ'
+CRVAL1  =    1.37835117405E+09
+CDELT1  =      9.765625000E+04
+CRPIX1  =                 32.0
+CUNIT1  = 'Hz'
+SPECSYS = 'TOPOCENT'
+RESTFRQ =      1.420405752E+09 / [Hz]
+RADESYS = 'FK5'
+"""
+
+
+@pytest.fixture
+def header_spectral_1d():
+    return Header.fromstring(HEADER_SPECTRAL_1D, sep='\n')
+
+
+@pytest.mark.parametrize(('ctype1', 'observer'), product(['ZOPT', 'BETA', 'VELO', 'VRAD', 'VOPT'], [False, True]))
+def test_spectral_1d(header_spectral_1d, ctype1, observer):
+
+    # This is a regression test for issues that happened with 1-d WCS
+    # where the target is not defined but observer is.
+
+    header = header_spectral_1d.copy()
+    header['CTYPE1'] = ctype1
+    header['CRVAL1'] = 0.1
+    header['CDELT1'] = 0.001
+
+    if ctype1[0] == 'V':
+        header['CUNIT1'] = 'm s-1'
+    else:
+        header['CUNIT1'] = ''
+
+    header['RESTWAV'] = 1.420405752E+09
+    header['MJD-OBS'] = 55197
+
+    if observer:
+        header['OBSGEO-L'] = 144.2
+        header['OBSGEO-B'] = -20.2
+        header['OBSGEO-H'] = 0.
+        header['SPECSYS'] = 'BARYCENT'
+
+    with warnings.catch_warnings():
+        warnings.simplefilter('ignore', FITSFixedWarning)
+        wcs = WCS(header)
+
+    # First ensure that transformations round-trip
+
+    spectralcoord = wcs.pixel_to_world(31)
+
+    assert isinstance(spectralcoord, SpectralCoord)
+    assert spectralcoord.target is None
+    assert (spectralcoord.observer is not None) is observer
+
+    if observer:
+        expected_message = 'No target defined on SpectralCoord'
+    else:
+        expected_message = 'No observer defined on WCS'
+
+    with pytest.warns(AstropyUserWarning, match=expected_message):
+        pix = wcs.world_to_pixel(spectralcoord)
+
+    assert_allclose(pix, [31], rtol=1e-6)
+
+    # Also make sure that we can convert a SpectralCoord on which the observer
+    # is not defined but the target is.
+
+    with pytest.warns(AstropyUserWarning, match='No velocity defined on frame'):
+        spectralcoord_no_obs = SpectralCoord(spectralcoord.quantity,
+                                             doppler_rest=spectralcoord.doppler_rest,
+                                             doppler_convention=spectralcoord.doppler_convention,
+                                             target=ICRS(10 * u.deg, 20 * u.deg, distance=1 * u.kpc))
+
+    if observer:
+        expected_message = 'No observer defined on SpectralCoord'
+    else:
+        expected_message = 'No observer defined on WCS'
+
+    with pytest.warns(AstropyUserWarning, match=expected_message):
+        pix2 = wcs.world_to_pixel(spectralcoord_no_obs)
+    assert_allclose(pix2, [31], rtol=1e-6)
+
+    # And finally check case when both observer and target are defined on the
+    # SpectralCoord
+
+    with pytest.warns(AstropyUserWarning, match='No velocity defined on frame'):
+        spectralcoord_no_obs = SpectralCoord(spectralcoord.quantity,
+                                             doppler_rest=spectralcoord.doppler_rest,
+                                             doppler_convention=spectralcoord.doppler_convention,
+                                             observer=ICRS(10 * u.deg, 20 * u.deg, distance=0 * u.kpc),
+                                             target=ICRS(10 * u.deg, 20 * u.deg, distance=1 * u.kpc))
+
+    if observer:
+        pix3 = wcs.world_to_pixel(spectralcoord_no_obs)
+    else:
+        with pytest.warns(AstropyUserWarning, match='No observer defined on WCS'):
+            pix3 = wcs.world_to_pixel(spectralcoord_no_obs)
+
+    assert_allclose(pix3, [31], rtol=1e-6)
+
+
+HEADER_SPECTRAL_WITH_TIME = """
+WCSAXES = 3
+CTYPE1  = 'RA---TAN'
+CTYPE2  = 'DEC--TAN'
+CTYPE3  = 'WAVE'
+CRVAL1  = 98.83153
+CRVAL2  = -66.818
+CRVAL3  = 6.4205
+CRPIX1  = 21.
+CRPIX2  = 22.
+CRPIX3  = 1.
+CDELT1  = 3.6111E-05
+CDELT2  = 3.6111E-05
+CDELT3  = 0.001
+CUNIT1  = 'deg'
+CUNIT2  = 'deg'
+CUNIT3  = 'um'
+MJD-AVG = 59045.41466
+RADESYS = 'ICRS'
+SPECSYS = 'BARYCENT'
+TIMESYS = 'UTC'
+"""
+
+
+@pytest.fixture
+def header_spectral_with_time():
+    return Header.fromstring(HEADER_SPECTRAL_WITH_TIME, sep='\n')
+
+
+def test_spectral_with_time_kw(header_spectral_with_time):
+    def check_wcs(header):
+        assert_allclose(w.all_pix2world(*w.wcs.crpix, 1), w.wcs.crval)
+        sky, spec = w.pixel_to_world(*w.wcs.crpix)
+        assert_allclose((sky.spherical.lon.degree, sky.spherical.lat.degree, spec.value),
+                        w.wcs.crval, rtol=1e-3)
+
+    # Chek with MJD-AVG and TIMESYS
+    hdr = header_spectral_with_time.copy()
+    with warnings.catch_warnings():
+        warnings.simplefilter('ignore', (VerifyWarning, FITSFixedWarning))
+        w = WCS(hdr)
+        # Make sure the correct keyword is used in a test
+        assert ~np.isnan(w.wcs.mjdavg)
+        assert np.isnan(w.wcs.mjdobs)
+
+    check_wcs(w)
+
+    # Check fall back to MJD-OBS
+    hdr['MJD-OBS'] = hdr['MJD-AVG']
+    del hdr['MJD-AVG']
+    with warnings.catch_warnings():
+        warnings.simplefilter('ignore', (VerifyWarning, FITSFixedWarning))
+        w = WCS(hdr)
+        # Make sure the correct keyword is used in a test
+        assert ~np.isnan(w.wcs.mjdobs)
+        assert np.isnan(w.wcs.mjdavg)
+    check_wcs(w)
+
+    # Check fall back to DATE--OBS
+    hdr['DATE-OBS'] = '2020-07-15'
+    del hdr['MJD-OBS']
+    with warnings.catch_warnings():
+        warnings.simplefilter('ignore', (VerifyWarning, FITSFixedWarning))
+        w = WCS(hdr)
+        w.wcs.mjdobs = np.nan
+        # Make sure the correct keyword is used in a test
+        assert np.isnan(w.wcs.mjdobs)
+        assert np.isnan(w.wcs.mjdavg)
+        assert w.wcs.dateobs != ""
+    check_wcs(hdr)
+
+    # Check fall back to scale='utc'
+    del hdr['TIMESYS']
+    check_wcs(hdr)
